beamtools.BeamSpanner
=====================

.. abjad-lineage:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner

.. autoclass:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.components
   :noindex:

.. autoattribute:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.leaves
   :noindex:

.. autoattribute:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.override
   :noindex:

.. autoattribute:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.set
   :noindex:

.. autoattribute:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.start_offset
   :noindex:

.. autoattribute:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.storage_format
   :noindex:

.. autoattribute:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.timespan
   :noindex:

.. autoattribute:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.written_duration
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.direction
   :noindex:

Methods
-------

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.append
   :noindex:

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.append_left
   :noindex:

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.clear
   :noindex:

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.extend
   :noindex:

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.extend_left
   :noindex:

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.fracture
   :noindex:

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.fuse
   :noindex:

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.index
   :noindex:

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.pop
   :noindex:

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.pop_left
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.__call__
   :noindex:

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.__contains__
   :noindex:

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.__eq__
   :noindex:

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.__ge__
   :noindex:

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.__gt__
   :noindex:

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.__le__
   :noindex:

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.__len__
   :noindex:

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.__lt__
   :noindex:

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.__ne__
   :noindex:

.. automethod:: abjad.tools.beamtools.BeamSpanner.BeamSpanner.BeamSpanner.__repr__
   :noindex:
